# Inq

<div align="center">

![Logo](https://raw.githubusercontent.com/robvanderleek/inq/main/docs/assets/logo-light.png)

</div>

<div align="center">

  *CLI for user input 🎙️*

</div>

Use `inq` for prompts in your shell commands/scripts.

For example, to show a checkbox:

```shell
uvx inq checkbox -m "Choose your toppings" -c Pepperoni -c Mushrooms -c Onions`
```

![Example](https://raw.githubusercontent.com/robvanderleek/inq/main/docs/assets/cli.gif)
